@@ -52,7 +52,7 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 =cut
 
-# $Id: docbook2man-spec.pl,v 1.6 2002/05/16 08:44:23 twaugh Exp $
+# $Id: docbook2man-spec.pl,v 1.7 2002/07/28 18:01:26 twaugh Exp $
 
 use SGMLS;			# Use the SGMLS package.
 use SGMLS::Output;		# Use stack-based output.
@@ -1154,6 +1154,10 @@ sgml('<XREF>', sub {
 man_sgml('|[lt    ]|', '<');
 man_sgml('|[gt    ]|', '>');
 man_sgml('|[amp   ]|', '&');
+man_sgml('|[minus ]|', '-');
+man_sgml('|[copy  ]|', '(C)');
+man_sgml('|[nbsp  ]|', '\~');
+man_sgml('|[thinsp]|', '\~');
 
 #
 # Default handlers (uncomment these if needed).  Right now, these are set
@@ -1214,9 +1218,7 @@ sgml('re', sub
 
 sgml('sdata',sub
 {
-	if($_[0] =~ /\[minus \]/) { output "-"; }
-	elsif($_[0] =~ /\[copy  \]/) { output "(C)"; }
-	else { die "Unknown SDATA: " . $_[0]; }
+	die "Unknown SDATA: " . $_[0];
 });
 sgml('pi',sub { die "Unknown processing instruction: " . $_[0]; });
 sgml('entity',sub { die "Unknown external entity: " . $_[0]->name; });
